@@ -240,24 +240,38 @@ bool ComputeZSpacingFromIPP(const DataSet &ds, double &zspacing)
     meanspacing += current;
     prev = distances[i];
     }
-  meanspacing /= (double)(nitems - 1);
-
-  //zspacing = distances[1] - distances[0];
-  zspacing = meanspacing;
-
-  // Check spacing is consistant:
-  const double ZTolerance = 1e-3; // ??? FIXME
-  prev = distances[0];
-  for(unsigned int i = 1; i < nitems; ++i)
+  bool timeseries = false;
+  if( nitems > 1 )
     {
-    const double current = distances[i] - prev;
-    if( fabs(current - zspacing) > ZTolerance )
+    meanspacing /= (double)(nitems - 1);
+    if( meanspacing == 0.0 )
       {
-      // For now simply gives up
-      gdcmErrorMacro( "This Enhanced Multiframe is not supported for now. Sorry" );
-      return false;
+      // Could be a time series. Assume time spacing of 1. for now:
+      gdcmDebugMacro( "Assuming time series for Z-spacing" );
+      meanspacing = 1.0;
+      timeseries = true;
+      }
+    }
+
+  zspacing = meanspacing;
+  assert( zspacing != 0.0 ); // technically this should not happen
+
+  if( !timeseries )
+    {
+    // Check spacing is consistant:
+    const double ZTolerance = 1e-3; // ??? FIXME
+    prev = distances[0];
+    for(unsigned int i = 1; i < nitems; ++i)
+      {
+      const double current = distances[i] - prev;
+      if( fabs(current - zspacing) > ZTolerance )
+        {
+        // For now simply gives up
+        gdcmErrorMacro( "This Enhanced Multiframe is not supported for now. Sorry" );
+        return false;
+        }
+      prev = distances[i];
       }
-    prev = distances[i];
     }
   return true;
 }
@@ -401,6 +415,7 @@ std::vector<double> ImageHelper::GetOriginValue(File const & f)
 
   if( ms == MediaStorage::EnhancedCTImageStorage
    || ms == MediaStorage::EnhancedMRImageStorage
+   || ms == MediaStorage::OphthalmicTomographyImageStorage
    || ms == MediaStorage::SegmentationStorage )
     {
     const Tag t1(0x5200,0x9229);
@@ -1049,6 +1064,7 @@ std::vector<double> ImageHelper::GetSpacingValue(File const & f)
 
   if( ms == MediaStorage::EnhancedCTImageStorage
     || ms == MediaStorage::EnhancedMRImageStorage
+    || ms == MediaStorage::OphthalmicTomographyImageStorage
     || ms == MediaStorage::SegmentationStorage )
     {
     // <entry group="5200" element="9230" vr="SQ" vm="1" name="Per-frame Functional Groups Sequence"/>
